# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: session/v1/session.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'session/v1/session.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from common.v1 import types_pb2 as common_dot_v1_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18session/v1/session.proto\x12\x18servicebridge.session.v1\x1a\x15\x63ommon/v1/types.proto\"\xdc\x08\n\x08\x45nvelope\x12\x0b\n\x03seq\x18\x01 \x01(\x04\x12\x0f\n\x07\x61\x63k_seq\x18\x02 \x01(\x04\x12\x14\n\x0ctimestamp_ms\x18\x03 \x01(\x03\x12\x30\n\x05hello\x18\n \x01(\x0b\x32\x1f.servicebridge.session.v1.HelloH\x00\x12\x37\n\thello_ack\x18\x0b \x01(\x0b\x32\".servicebridge.session.v1.HelloAckH\x00\x12\x36\n\x05\x64rain\x18\x0c \x01(\x0b\x32%.servicebridge.session.v1.DrainSignalH\x00\x12\x38\n\x06goaway\x18\r \x01(\x0b\x32&.servicebridge.session.v1.GoawaySignalH\x00\x12\x33\n\x04ping\x18\x14 \x01(\x0b\x32#.servicebridge.session.v1.PingFrameH\x00\x12\x33\n\x04pong\x18\x15 \x01(\x0b\x32#.servicebridge.session.v1.PongFrameH\x00\x12\x41\n\x0e\x63ommand_result\x18\x1e \x01(\x0b\x32\'.servicebridge.session.v1.CommandResultH\x00\x12=\n\ttelemetry\x18\x1f \x01(\x0b\x32(.servicebridge.session.v1.TelemetryFrameH\x00\x12\x44\n\rstream_append\x18  \x01(\x0b\x32+.servicebridge.session.v1.StreamAppendFrameH\x00\x12\x44\n\rworker_status\x18! \x01(\x0b\x32+.servicebridge.session.v1.WorkerStatusFrameH\x00\x12\x43\n\x0fposition_update\x18\" \x01(\x0b\x32(.servicebridge.session.v1.PositionUpdateH\x00\x12=\n\x08\x64ispatch\x18( \x01(\x0b\x32).servicebridge.session.v1.DispatchCommandH\x00\x12;\n\x0b\x63onfig_push\x18) \x01(\x0b\x32$.servicebridge.session.v1.ConfigPushH\x00\x12=\n\x0cpermit_grant\x18\x32 \x01(\x0b\x32%.servicebridge.session.v1.PermitGrantH\x00\x12\x41\n\x0epermit_release\x18\x33 \x01(\x0b\x32\'.servicebridge.session.v1.PermitReleaseH\x00\x12\x42\n\x0b\x66low_update\x18\x34 \x01(\x0b\x32+.servicebridge.session.v1.FlowControlUpdateH\x00\x12\x35\n\x05\x65rror\x18\x63 \x01(\x0b\x32$.servicebridge.session.v1.ErrorFrameH\x00\x42\t\n\x07payload\"\xdd\x02\n\x05Hello\x12\x39\n\x08identity\x18\x01 \x01(\x0b\x32\'.servicebridge.common.v1.WorkerIdentity\x12\x14\n\x0cmax_inflight\x18\x02 \x01(\x05\x12\x14\n\x0cmin_inflight\x18\x03 \x01(\x05\x12\x14\n\x0cresume_token\x18\x04 \x01(\t\x12\r\n\x05\x65poch\x18\x05 \x01(\x04\x12\x19\n\x11last_received_seq\x18\x06 \x01(\x04\x12\x15\n\rlast_sent_seq\x18\x07 \x01(\x04\x12\x1d\n\x15\x63ompleted_command_ids\x18\x08 \x03(\t\x12\x13\n\x0bsdk_version\x18\n \x01(\t\x12\x14\n\x0c\x63\x61pabilities\x18\x0b \x03(\t\x12\x0c\n\x04zone\x18\x0c \x01(\t\x12>\n\x0etransport_mode\x18\r \x01(\x0e\x32&.servicebridge.common.v1.TransportMode\"\xa1\x03\n\x08HelloAck\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x14\n\x0cresume_token\x18\x02 \x01(\t\x12\r\n\x05\x65poch\x18\x03 \x01(\x04\x12\x0f\n\x07resumed\x18\x04 \x01(\x08\x12\x17\n\x0fresume_from_seq\x18\x05 \x01(\x04\x12\x19\n\x11replayed_commands\x18\x06 \x01(\x05\x12\x1a\n\x12reconciled_results\x18\x07 \x01(\x05\x12\x1d\n\x15heartbeat_interval_ms\x18\n \x01(\x05\x12\x1c\n\x14heartbeat_timeout_ms\x18\x0b \x01(\x05\x12\x17\n\x0finitial_permits\x18\x0c \x01(\x05\x12\x13\n\x0bmax_permits\x18\r \x01(\x05\x12H\n\x18\x65\x66\x66\x65\x63tive_transport_mode\x18\x14 \x01(\x0e\x32&.servicebridge.common.v1.TransportMode\x12\x46\n\x12resume_fail_reason\x18\x1e \x01(\x0e\x32*.servicebridge.session.v1.ResumeFailReason\"O\n\x0b\x44rainSignal\x12\x0e\n\x06reason\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65\x61\x64line_ms\x18\x02 \x01(\x05\x12\x1b\n\x13pending_command_ids\x18\x03 \x03(\t\"R\n\x0cGoawaySignal\x12\x32\n\x04\x63ode\x18\x01 \x01(\x0e\x32$.servicebridge.session.v1.GoawayCode\x12\x0e\n\x06reason\x18\x02 \x01(\t\"!\n\tPingFrame\x12\x14\n\x0ctimestamp_ms\x18\x01 \x01(\x03\"C\n\tPongFrame\x12\x19\n\x11\x65\x63ho_timestamp_ms\x18\x01 \x01(\x03\x12\x1b\n\x13server_timestamp_ms\x18\x02 \x01(\x03\"\xc2\x01\n\x0f\x44ispatchCommand\x12\x12\n\ncommand_id\x18\x01 \x01(\t\x12\x18\n\x10\x64\x65\x61\x64line_unix_ms\x18\x02 \x01(\x03\x12\x11\n\tis_replay\x18\x03 \x01(\x08\x12\x30\n\x03rpc\x18\n \x01(\x0b\x32!.servicebridge.session.v1.RpcTaskH\x00\x12\x34\n\x05\x65vent\x18\x0b \x01(\x0b\x32#.servicebridge.session.v1.EventTaskH\x00\x42\x06\n\x04task\"Y\n\x07RpcTask\x12\n\n\x02\x66n\x18\x01 \x01(\t\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\x12\x10\n\x08trace_id\x18\x03 \x01(\t\x12\x0f\n\x07span_id\x18\x04 \x01(\t\x12\x0e\n\x06run_id\x18\x05 \x01(\t\"\x91\x02\n\tEventTask\x12\x12\n\nmessage_id\x18\x01 \x01(\t\x12\x12\n\ngroup_name\x18\x02 \x01(\t\x12\r\n\x05topic\x18\x03 \x01(\t\x12\x0f\n\x07payload\x18\x04 \x01(\x0c\x12\x41\n\x07headers\x18\x05 \x03(\x0b\x32\x30.servicebridge.session.v1.EventTask.HeadersEntry\x12\x10\n\x08trace_id\x18\x06 \x01(\t\x12\x16\n\x0eparent_span_id\x18\x07 \x01(\t\x12\x0f\n\x07\x61ttempt\x18\x08 \x01(\x05\x12\x0e\n\x06run_id\x18\t \x01(\t\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa3\x01\n\rCommandResult\x12\x12\n\ncommand_id\x18\x01 \x01(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x0e\n\x06output\x18\x03 \x01(\x0c\x12\r\n\x05\x65rror\x18\x04 \x01(\t\x12\x0b\n\x03\x61\x63k\x18\x05 \x01(\x08\x12\x16\n\x0eretry_after_ms\x18\x06 \x01(\x05\x12\x15\n\rreject_reason\x18\x07 \x01(\t\x12\x12\n\nresult_seq\x18\x08 \x01(\x04\"v\n\x0eTelemetryFrame\x12\x32\n\x05spans\x18\x01 \x03(\x0b\x32#.servicebridge.session.v1.SpanEvent\x12\x30\n\x04logs\x18\x02 \x03(\x0b\x32\".servicebridge.session.v1.LogEntry\"\xc2\x02\n\tSpanEvent\x12\x36\n\x04kind\x18\x01 \x01(\x0e\x32(.servicebridge.session.v1.SpanEvent.Kind\x12\x10\n\x08trace_id\x18\x02 \x01(\t\x12\x0f\n\x07span_id\x18\x03 \x01(\t\x12\x16\n\x0eparent_span_id\x18\x04 \x01(\t\x12\n\n\x02\x66n\x18\x05 \x01(\t\x12\x12\n\nstarted_at\x18\x06 \x01(\x03\x12\x13\n\x0b\x64uration_ms\x18\x07 \x01(\x03\x12\x0f\n\x07success\x18\x08 \x01(\x08\x12\r\n\x05\x65rror\x18\t \x01(\t\x12\r\n\x05input\x18\n \x01(\x0c\x12\x0e\n\x06output\x18\x0b \x01(\x0c\x12\x0f\n\x07\x61ttempt\x18\x0c \x01(\x05\"=\n\x04Kind\x12\x14\n\x10KIND_UNSPECIFIED\x10\x00\x12\x0e\n\nKIND_START\x10\x01\x12\x0f\n\x0bKIND_FINISH\x10\x02\"\x89\x02\n\x08LogEntry\x12\x10\n\x08trace_id\x18\x01 \x01(\t\x12\x0f\n\x07span_id\x18\x02 \x01(\t\x12\x14\n\x0cservice_name\x18\x03 \x01(\t\x12\r\n\x05level\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\x12\x14\n\x0ctimestamp_ns\x18\x06 \x01(\x03\x12\x46\n\nattributes\x18\x07 \x03(\x0b\x32\x32.servicebridge.session.v1.LogEntry.AttributesEntry\x12\x13\n\x0binstance_id\x18\x08 \x01(\t\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"f\n\x11StreamAppendFrame\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x12\n\nevent_type\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x0c\x12\x12\n\nrun_status\x18\x05 \x01(\t\"\x85\x01\n\x11WorkerStatusFrame\x12\x16\n\x0e\x66unction_names\x18\x01 \x03(\t\x12\x13\n\x0bgroup_names\x18\x02 \x03(\t\x12\x10\n\x08\x65ndpoint\x18\x03 \x01(\t\x12\x13\n\x0b\x63pu_percent\x18\x04 \x01(\x02\x12\x0e\n\x06ram_mb\x18\x05 \x01(\x05\x12\x0c\n\x04zone\x18\x06 \x01(\t\"@\n\x0bPermitGrant\x12\x1a\n\x12\x61\x64\x64itional_permits\x18\x01 \x01(\x05\x12\x15\n\rtotal_pending\x18\x02 \x01(\x05\"!\n\rPermitRelease\x12\x10\n\x08released\x18\x01 \x01(\x05\"<\n\x11\x46lowControlUpdate\x12\x17\n\x0fnew_window_size\x18\x01 \x01(\x05\x12\x0e\n\x06reason\x18\x02 \x01(\t\"+\n\x0ePositionUpdate\x12\x19\n\x11last_received_seq\x18\x01 \x01(\x04\"Q\n\nConfigPush\x12\x43\n\x10transport_config\x18\x01 \x01(\x0b\x32).servicebridge.session.v1.TransportConfig\"\xea\x04\n\x0fTransportConfig\x12<\n\x0c\x64\x65\x66\x61ult_mode\x18\x01 \x01(\x0e\x32&.servicebridge.common.v1.TransportMode\x12Z\n\x11service_overrides\x18\x02 \x03(\x0b\x32?.servicebridge.session.v1.TransportConfig.ServiceOverridesEntry\x12\\\n\x12\x66unction_overrides\x18\x03 \x03(\x0b\x32@.servicebridge.session.v1.TransportConfig.FunctionOverridesEntry\x12O\n\x17\x64\x65\x66\x61ult_circuit_breaker\x18\x04 \x01(\x0b\x32..servicebridge.session.v1.CircuitBreakerConfig\x12\x32\n\x04zone\x18\x05 \x01(\x0b\x32$.servicebridge.session.v1.ZoneConfig\x1ak\n\x15ServiceOverridesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x41\n\x05value\x18\x02 \x01(\x0b\x32\x32.servicebridge.session.v1.ServiceTransportOverride:\x02\x38\x01\x1am\n\x16\x46unctionOverridesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x42\n\x05value\x18\x02 \x01(\x0b\x32\x33.servicebridge.session.v1.FunctionTransportOverride:\x02\x38\x01\"\xb8\x02\n\x18ServiceTransportOverride\x12\x34\n\x04mode\x18\x01 \x01(\x0e\x32&.servicebridge.common.v1.TransportMode\x12\x41\n\x0f\x66\x61llback_policy\x18\x02 \x01(\x0e\x32(.servicebridge.session.v1.FallbackPolicy\x12\x19\n\x11\x64irect_timeout_ms\x18\x03 \x01(\x05\x12?\n\tlb_policy\x18\x04 \x01(\x0e\x32,.servicebridge.common.v1.LoadBalancingPolicy\x12G\n\x0f\x63ircuit_breaker\x18\x05 \x01(\x0b\x32..servicebridge.session.v1.CircuitBreakerConfig\"\xa8\x01\n\x19\x46unctionTransportOverride\x12\x34\n\x04mode\x18\x01 \x01(\x0e\x32&.servicebridge.common.v1.TransportMode\x12\x41\n\x0f\x66\x61llback_policy\x18\x02 \x01(\x0e\x32(.servicebridge.session.v1.FallbackPolicy\x12\x12\n\ntimeout_ms\x18\x03 \x01(\x05\"\x86\x01\n\x14\x43ircuitBreakerConfig\x12\x19\n\x11\x66\x61ilure_threshold\x18\x01 \x01(\x05\x12\x19\n\x11success_threshold\x18\x02 \x01(\x05\x12\x18\n\x10open_duration_ms\x18\x03 \x01(\x05\x12\x1e\n\x16half_open_max_requests\x18\x04 \x01(\x05\"P\n\nZoneConfig\x12\x12\n\nlocal_zone\x18\x01 \x01(\t\x12\x13\n\x0bprefer_zone\x18\x02 \x01(\x08\x12\x19\n\x11zone_weight_boost\x18\x03 \x01(\x05\"V\n\nErrorFrame\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x11\n\tretryable\x18\x03 \x01(\x08\x12\x16\n\x0eretry_after_ms\x18\x04 \x01(\x05*\xec\x01\n\x10ResumeFailReason\x12\x1b\n\x17RESUME_FAIL_UNSPECIFIED\x10\x00\x12\x1d\n\x19RESUME_FAIL_TOKEN_EXPIRED\x10\x01\x12\x1d\n\x19RESUME_FAIL_TOKEN_INVALID\x10\x02\x12\x1d\n\x19RESUME_FAIL_GAP_TOO_LARGE\x10\x03\x12\x1e\n\x1aRESUME_FAIL_EPOCH_MISMATCH\x10\x04\x12\x1e\n\x1aRESUME_FAIL_SESSION_FENCED\x10\x05\x12\x1e\n\x1aRESUME_FAIL_SERVER_RESTART\x10\x06*\x80\x01\n\nGoawayCode\x12\x12\n\x0eGOAWAY_UNKNOWN\x10\x00\x12\x1c\n\x18GOAWAY_GRACEFUL_SHUTDOWN\x10\x01\x12\x15\n\x11GOAWAY_OVERLOADED\x10\x02\x12\x11\n\rGOAWAY_FENCED\x10\x03\x12\x16\n\x12GOAWAY_MAINTENANCE\x10\x04*l\n\x0e\x46\x61llbackPolicy\x12\x11\n\rFALLBACK_NONE\x10\x00\x12\x15\n\x11\x46\x41LLBACK_TO_PROXY\x10\x01\x12\x16\n\x12\x46\x41LLBACK_TO_DIRECT\x10\x02\x12\x18\n\x14\x46\x41LLBACK_BEST_EFFORT\x10\x03\x32g\n\x0eSessionService\x12U\n\x07\x43hannel\x12\".servicebridge.session.v1.Envelope\x1a\".servicebridge.session.v1.Envelope(\x01\x30\x01\x42\x45ZCgithub.com/servicebridge/server-go/internal/pb/session/v1;sessionv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'session.v1.session_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZCgithub.com/servicebridge/server-go/internal/pb/session/v1;sessionv1'
  _globals['_EVENTTASK_HEADERSENTRY']._loaded_options = None
  _globals['_EVENTTASK_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_LOGENTRY_ATTRIBUTESENTRY']._loaded_options = None
  _globals['_LOGENTRY_ATTRIBUTESENTRY']._serialized_options = b'8\001'
  _globals['_TRANSPORTCONFIG_SERVICEOVERRIDESENTRY']._loaded_options = None
  _globals['_TRANSPORTCONFIG_SERVICEOVERRIDESENTRY']._serialized_options = b'8\001'
  _globals['_TRANSPORTCONFIG_FUNCTIONOVERRIDESENTRY']._loaded_options = None
  _globals['_TRANSPORTCONFIG_FUNCTIONOVERRIDESENTRY']._serialized_options = b'8\001'
  _globals['_RESUMEFAILREASON']._serialized_start=5626
  _globals['_RESUMEFAILREASON']._serialized_end=5862
  _globals['_GOAWAYCODE']._serialized_start=5865
  _globals['_GOAWAYCODE']._serialized_end=5993
  _globals['_FALLBACKPOLICY']._serialized_start=5995
  _globals['_FALLBACKPOLICY']._serialized_end=6103
  _globals['_ENVELOPE']._serialized_start=78
  _globals['_ENVELOPE']._serialized_end=1194
  _globals['_HELLO']._serialized_start=1197
  _globals['_HELLO']._serialized_end=1546
  _globals['_HELLOACK']._serialized_start=1549
  _globals['_HELLOACK']._serialized_end=1966
  _globals['_DRAINSIGNAL']._serialized_start=1968
  _globals['_DRAINSIGNAL']._serialized_end=2047
  _globals['_GOAWAYSIGNAL']._serialized_start=2049
  _globals['_GOAWAYSIGNAL']._serialized_end=2131
  _globals['_PINGFRAME']._serialized_start=2133
  _globals['_PINGFRAME']._serialized_end=2166
  _globals['_PONGFRAME']._serialized_start=2168
  _globals['_PONGFRAME']._serialized_end=2235
  _globals['_DISPATCHCOMMAND']._serialized_start=2238
  _globals['_DISPATCHCOMMAND']._serialized_end=2432
  _globals['_RPCTASK']._serialized_start=2434
  _globals['_RPCTASK']._serialized_end=2523
  _globals['_EVENTTASK']._serialized_start=2526
  _globals['_EVENTTASK']._serialized_end=2799
  _globals['_EVENTTASK_HEADERSENTRY']._serialized_start=2753
  _globals['_EVENTTASK_HEADERSENTRY']._serialized_end=2799
  _globals['_COMMANDRESULT']._serialized_start=2802
  _globals['_COMMANDRESULT']._serialized_end=2965
  _globals['_TELEMETRYFRAME']._serialized_start=2967
  _globals['_TELEMETRYFRAME']._serialized_end=3085
  _globals['_SPANEVENT']._serialized_start=3088
  _globals['_SPANEVENT']._serialized_end=3410
  _globals['_SPANEVENT_KIND']._serialized_start=3349
  _globals['_SPANEVENT_KIND']._serialized_end=3410
  _globals['_LOGENTRY']._serialized_start=3413
  _globals['_LOGENTRY']._serialized_end=3678
  _globals['_LOGENTRY_ATTRIBUTESENTRY']._serialized_start=3629
  _globals['_LOGENTRY_ATTRIBUTESENTRY']._serialized_end=3678
  _globals['_STREAMAPPENDFRAME']._serialized_start=3680
  _globals['_STREAMAPPENDFRAME']._serialized_end=3782
  _globals['_WORKERSTATUSFRAME']._serialized_start=3785
  _globals['_WORKERSTATUSFRAME']._serialized_end=3918
  _globals['_PERMITGRANT']._serialized_start=3920
  _globals['_PERMITGRANT']._serialized_end=3984
  _globals['_PERMITRELEASE']._serialized_start=3986
  _globals['_PERMITRELEASE']._serialized_end=4019
  _globals['_FLOWCONTROLUPDATE']._serialized_start=4021
  _globals['_FLOWCONTROLUPDATE']._serialized_end=4081
  _globals['_POSITIONUPDATE']._serialized_start=4083
  _globals['_POSITIONUPDATE']._serialized_end=4126
  _globals['_CONFIGPUSH']._serialized_start=4128
  _globals['_CONFIGPUSH']._serialized_end=4209
  _globals['_TRANSPORTCONFIG']._serialized_start=4212
  _globals['_TRANSPORTCONFIG']._serialized_end=4830
  _globals['_TRANSPORTCONFIG_SERVICEOVERRIDESENTRY']._serialized_start=4612
  _globals['_TRANSPORTCONFIG_SERVICEOVERRIDESENTRY']._serialized_end=4719
  _globals['_TRANSPORTCONFIG_FUNCTIONOVERRIDESENTRY']._serialized_start=4721
  _globals['_TRANSPORTCONFIG_FUNCTIONOVERRIDESENTRY']._serialized_end=4830
  _globals['_SERVICETRANSPORTOVERRIDE']._serialized_start=4833
  _globals['_SERVICETRANSPORTOVERRIDE']._serialized_end=5145
  _globals['_FUNCTIONTRANSPORTOVERRIDE']._serialized_start=5148
  _globals['_FUNCTIONTRANSPORTOVERRIDE']._serialized_end=5316
  _globals['_CIRCUITBREAKERCONFIG']._serialized_start=5319
  _globals['_CIRCUITBREAKERCONFIG']._serialized_end=5453
  _globals['_ZONECONFIG']._serialized_start=5455
  _globals['_ZONECONFIG']._serialized_end=5535
  _globals['_ERRORFRAME']._serialized_start=5537
  _globals['_ERRORFRAME']._serialized_end=5623
  _globals['_SESSIONSERVICE']._serialized_start=6105
  _globals['_SESSIONSERVICE']._serialized_end=6208
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: controlplane/v1/control_plane.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'controlplane/v1/control_plane.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from common.v1 import types_pb2 as common_dot_v1_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#controlplane/v1/control_plane.proto\x12\x1dservicebridge.controlplane.v1\x1a\x15\x63ommon/v1/types.proto\"\x9f\x04\n\x10ReconcileRequest\x12\x39\n\x08identity\x18\x01 \x01(\x0b\x32\'.servicebridge.common.v1.WorkerIdentity\x12?\n\tfunctions\x18\x02 \x03(\x0b\x32,.servicebridge.common.v1.FunctionDeclaration\x12J\n\x0f\x63onsumer_groups\x18\x03 \x03(\x0b\x32\x31.servicebridge.common.v1.ConsumerGroupDeclaration\x12\x42\n\x0bhttp_routes\x18\x04 \x03(\x0b\x32-.servicebridge.common.v1.HttpRouteDeclaration\x12?\n\tworkflows\x18\x05 \x03(\x0b\x32,.servicebridge.common.v1.WorkflowDeclaration\x12\x35\n\x04jobs\x18\x06 \x03(\x0b\x32\'.servicebridge.common.v1.JobDeclaration\x12\x39\n\x07metrics\x18\x07 \x01(\x0b\x32(.servicebridge.common.v1.ResourceMetrics\x12>\n\x0etransport_mode\x18\x08 \x01(\x0e\x32&.servicebridge.common.v1.TransportMode\x12\x0c\n\x04zone\x18\t \x01(\t\"B\n\x11ReconcileResponse\x12\x14\n\x0clease_ttl_ms\x18\x01 \x01(\x03\x12\x17\n\x0fserver_revision\x18\x02 \x01(\x03\"\x84\x01\n\x17IssueCertificateRequest\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x13\n\x0binstance_id\x18\x02 \x01(\t\x12\x0f\n\x07\x63sr_pem\x18\x03 \x01(\t\x12\x19\n\x11\x61\x64vertise_address\x18\x04 \x01(\t\x12\x12\n\nextra_sans\x18\x05 \x03(\t\"P\n\x18IssueCertificateResponse\x12\x10\n\x08\x63\x65rt_pem\x18\x01 \x01(\t\x12\x0e\n\x06\x63\x61_pem\x18\x02 \x01(\t\x12\x12\n\nexpires_at\x18\x03 \x01(\x03\"\xbf\x01\n\x0ePublishRequest\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\x12K\n\x07headers\x18\x03 \x03(\x0b\x32:.servicebridge.controlplane.v1.PublishRequest.HeadersEntry\x12\x10\n\x08trace_id\x18\x04 \x01(\t\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"%\n\x0fPublishResponse\x12\x12\n\nmessage_id\x18\x01 \x01(\t\"\\\n\x12RunWorkflowRequest\x12\x15\n\rworkflow_name\x18\x01 \x01(\t\x12\r\n\x05input\x18\x02 \x01(\x0c\x12\x0e\n\x06run_id\x18\x03 \x01(\t\x12\x10\n\x08trace_id\x18\x04 \x01(\t\"%\n\x13RunWorkflowResponse\x12\x0e\n\x06run_id\x18\x01 \x01(\t\"7\n\x15\x43\x61ncelWorkflowRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"+\n\x16\x43\x61ncelWorkflowResponse\x12\x11\n\tcancelled\x18\x01 \x01(\x08\"\x81\x01\n\x10ProxyCallRequest\x12\x15\n\rfunction_name\x18\x01 \x01(\t\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\x12\x10\n\x08trace_id\x18\x03 \x01(\t\x12\x0f\n\x07span_id\x18\x04 \x01(\t\x12\x0e\n\x06run_id\x18\x05 \x01(\t\x12\x12\n\ntimeout_ms\x18\x06 \x01(\x05\"C\n\x11ProxyCallResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0e\n\x06output\x18\x02 \x01(\x0c\x12\r\n\x05\x65rror\x18\x03 \x01(\t2\xd3\x05\n\x0c\x43ontrolPlane\x12n\n\tReconcile\x12/.servicebridge.controlplane.v1.ReconcileRequest\x1a\x30.servicebridge.controlplane.v1.ReconcileResponse\x12\x83\x01\n\x10IssueCertificate\x12\x36.servicebridge.controlplane.v1.IssueCertificateRequest\x1a\x37.servicebridge.controlplane.v1.IssueCertificateResponse\x12h\n\x07Publish\x12-.servicebridge.controlplane.v1.PublishRequest\x1a..servicebridge.controlplane.v1.PublishResponse\x12t\n\x0bRunWorkflow\x12\x31.servicebridge.controlplane.v1.RunWorkflowRequest\x1a\x32.servicebridge.controlplane.v1.RunWorkflowResponse\x12}\n\x0e\x43\x61ncelWorkflow\x12\x34.servicebridge.controlplane.v1.CancelWorkflowRequest\x1a\x35.servicebridge.controlplane.v1.CancelWorkflowResponse\x12n\n\tProxyCall\x12/.servicebridge.controlplane.v1.ProxyCallRequest\x1a\x30.servicebridge.controlplane.v1.ProxyCallResponseBOZMgithub.com/servicebridge/server-go/internal/pb/controlplane/v1;controlplanev1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'controlplane.v1.control_plane_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZMgithub.com/servicebridge/server-go/internal/pb/controlplane/v1;controlplanev1'
  _globals['_PUBLISHREQUEST_HEADERSENTRY']._loaded_options = None
  _globals['_PUBLISHREQUEST_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_RECONCILEREQUEST']._serialized_start=94
  _globals['_RECONCILEREQUEST']._serialized_end=637
  _globals['_RECONCILERESPONSE']._serialized_start=639
  _globals['_RECONCILERESPONSE']._serialized_end=705
  _globals['_ISSUECERTIFICATEREQUEST']._serialized_start=708
  _globals['_ISSUECERTIFICATEREQUEST']._serialized_end=840
  _globals['_ISSUECERTIFICATERESPONSE']._serialized_start=842
  _globals['_ISSUECERTIFICATERESPONSE']._serialized_end=922
  _globals['_PUBLISHREQUEST']._serialized_start=925
  _globals['_PUBLISHREQUEST']._serialized_end=1116
  _globals['_PUBLISHREQUEST_HEADERSENTRY']._serialized_start=1070
  _globals['_PUBLISHREQUEST_HEADERSENTRY']._serialized_end=1116
  _globals['_PUBLISHRESPONSE']._serialized_start=1118
  _globals['_PUBLISHRESPONSE']._serialized_end=1155
  _globals['_RUNWORKFLOWREQUEST']._serialized_start=1157
  _globals['_RUNWORKFLOWREQUEST']._serialized_end=1249
  _globals['_RUNWORKFLOWRESPONSE']._serialized_start=1251
  _globals['_RUNWORKFLOWRESPONSE']._serialized_end=1288
  _globals['_CANCELWORKFLOWREQUEST']._serialized_start=1290
  _globals['_CANCELWORKFLOWREQUEST']._serialized_end=1345
  _globals['_CANCELWORKFLOWRESPONSE']._serialized_start=1347
  _globals['_CANCELWORKFLOWRESPONSE']._serialized_end=1390
  _globals['_PROXYCALLREQUEST']._serialized_start=1393
  _globals['_PROXYCALLREQUEST']._serialized_end=1522
  _globals['_PROXYCALLRESPONSE']._serialized_start=1524
  _globals['_PROXYCALLRESPONSE']._serialized_end=1591
  _globals['_CONTROLPLANE']._serialized_start=1594
  _globals['_CONTROLPLANE']._serialized_end=2317
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: common/v1/types.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'common/v1/types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x63ommon/v1/types.proto\x12\x17servicebridge.common.v1\"`\n\x0eWorkerIdentity\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x13\n\x0binstance_id\x18\x02 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x03 \x01(\t\x12\x11\n\ttransport\x18\x04 \x01(\t\"[\n\x0fResourceMetrics\x12\x18\n\x0b\x63pu_percent\x18\x01 \x01(\x02H\x00\x88\x01\x01\x12\x13\n\x06ram_mb\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x0e\n\x0c_cpu_percentB\t\n\x07_ram_mb\"\x86\x01\n\x13\x46unctionDeclaration\x12\x0f\n\x07\x66n_name\x18\x01 \x01(\t\x12\x0e\n\x06weight\x18\x02 \x01(\x05\x12\x19\n\x11input_schema_json\x18\x03 \x01(\t\x12\x1a\n\x12output_schema_json\x18\x04 \x01(\t\x12\x17\n\x0f\x61llowed_callers\x18\x05 \x03(\t\"\x97\x01\n\x18\x43onsumerGroupDeclaration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07pattern\x18\x02 \x01(\t\x12\x0c\n\x04mode\x18\x03 \x01(\t\x12\x19\n\x11retry_policy_json\x18\x04 \x01(\t\x12\x0e\n\x06\x61\x63tive\x18\x05 \x01(\x08\x12\x13\n\x0b\x66ilter_expr\x18\x06 \x01(\t\x12\x0e\n\x06weight\x18\x07 \x01(\x05\"\x91\x01\n\x14HttpRouteDeclaration\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x15\n\rroute_pattern\x18\x02 \x01(\t\x12\x1b\n\x13request_schema_json\x18\x03 \x01(\t\x12\x1c\n\x14response_schema_json\x18\x04 \x01(\t\x12\x17\n\x0f\x61llowed_callers\x18\x05 \x03(\t\"E\n\x13WorkflowDeclaration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ndefinition\x18\x02 \x01(\t\x12\x0c\n\x04opts\x18\x03 \x01(\t\"\xa3\x01\n\x0eJobDeclaration\x12\x11\n\tcron_expr\x18\x01 \x01(\t\x12\x10\n\x08timezone\x18\x02 \x01(\t\x12\x16\n\x0emisfire_policy\x18\x03 \x01(\t\x12\x13\n\x0btarget_type\x18\x04 \x01(\t\x12\x12\n\ntarget_ref\x18\x05 \x01(\t\x12\x10\n\x08\x64\x65lay_ms\x18\x06 \x01(\x05\x12\x19\n\x11retry_policy_json\x18\x07 \x01(\t*d\n\rTransportMode\x12\x1e\n\x1aTRANSPORT_MODE_UNSPECIFIED\x10\x00\x12\x19\n\x15TRANSPORT_MODE_DIRECT\x10\x01\x12\x18\n\x14TRANSPORT_MODE_PROXY\x10\x02*g\n\x13LoadBalancingPolicy\x12\x12\n\x0eLB_ROUND_ROBIN\x10\x00\x12\x0f\n\x0bLB_WEIGHTED\x10\x01\x12\x18\n\x14LB_LEAST_CONNECTIONS\x10\x02\x12\x11\n\rLB_ZONE_AWARE\x10\x03*C\n\x13\x43ircuitBreakerState\x12\r\n\tCB_CLOSED\x10\x00\x12\x0b\n\x07\x43\x42_OPEN\x10\x01\x12\x10\n\x0c\x43\x42_HALF_OPEN\x10\x02\x42\x43ZAgithub.com/servicebridge/server-go/internal/pb/common/v1;commonv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/servicebridge/server-go/internal/pb/common/v1;commonv1'
  _globals['_TRANSPORTMODE']._serialized_start=917
  _globals['_TRANSPORTMODE']._serialized_end=1017
  _globals['_LOADBALANCINGPOLICY']._serialized_start=1019
  _globals['_LOADBALANCINGPOLICY']._serialized_end=1122
  _globals['_CIRCUITBREAKERSTATE']._serialized_start=1124
  _globals['_CIRCUITBREAKERSTATE']._serialized_end=1191
  _globals['_WORKERIDENTITY']._serialized_start=50
  _globals['_WORKERIDENTITY']._serialized_end=146
  _globals['_RESOURCEMETRICS']._serialized_start=148
  _globals['_RESOURCEMETRICS']._serialized_end=239
  _globals['_FUNCTIONDECLARATION']._serialized_start=242
  _globals['_FUNCTIONDECLARATION']._serialized_end=376
  _globals['_CONSUMERGROUPDECLARATION']._serialized_start=379
  _globals['_CONSUMERGROUPDECLARATION']._serialized_end=530
  _globals['_HTTPROUTEDECLARATION']._serialized_start=533
  _globals['_HTTPROUTEDECLARATION']._serialized_end=678
  _globals['_WORKFLOWDECLARATION']._serialized_start=680
  _globals['_WORKFLOWDECLARATION']._serialized_end=749
  _globals['_JOBDECLARATION']._serialized_start=752
  _globals['_JOBDECLARATION']._serialized_end=915
# @@protoc_insertion_point(module_scope)
